Jake.Stine 2f8f86a3eb Significant VIFunpack retooling. Interpreters are considerably more efficient, and Recompilers are slightly more efficient. Details:
* All remaining code for handling partial/fragmented unpacks removed.
 * vifRegs.NUM is now accurately simulated when queuing data from fragmented unpacks.
 * Reduced the VIFunpack fragment buffer from 1MB to 4KB (max size of an unpack due to NUM being limited to 8 bits).
 * Removed vif/vifRegs globals formally used by VIF interpreters (everything relies on the templated vifIdx now -- simpler and faster!)
 * g_vifMask vars are integrated into vifStruct.
 * All VIF mask register stuff uses the SSE-friendly vifStruct.MaskRow/Col vars now.

git-svn-id: http://pcsx2.googlecode.com/svn/trunk@3762 96395faa-99c1-11dd-bbfe-3dabce05a288
2010-09-13 21:13:10 +00:00
2010-08-27 13:48:41 +00:00
2010-09-13 15:26:04 +00:00
2010-09-12 14:27:33 +00:00
2010-09-13 15:26:04 +00:00
S
Description
PCSX2 - The Playstation 2 Emulator
693 MiB
0 Stars 1 Watchers 0 Forks
Languages
C++ 88.5%
C 2.8%
HTML 2.5%
GLSL 1.2%
Objective-C++ 1%
Other 3.8%